==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseArcCPPA/ts/EllipseArcCPPA_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>EllipseArcCPPA</name>
    <message>
        <location filename="../EllipseArcCPPA.js" line="+74"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Major point of ellipse or major radius</source>
        <translation>Glavna točka elipse ali velik radij</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Major point of ellipse</source>
        <translation>Glavna točka elipse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Minor point of ellipse or minor radius</source>
        <translation>Druga točka elipse ali mali radij</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Minor point of ellipse</source>
        <translation>Druga točka elipse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Rotation angle</source>
        <translation>Kot rotacije</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start parameter</source>
        <translation>Začetni parameter</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End parameter</source>
        <translation>Končni parameter</translation>
    </message>
    <message>
        <location line="+264"/>
        <source>Invalid major radius.</source>
        <translation>Neveljaven velik radij.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Major radius:</source>
        <translation>Velik radij:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Minor radius:</source>
        <translation>Majhen radij:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Start angle:</source>
        <translation>Začetni kot:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>End angle:</source>
        <translation>Končni kot:</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Nasprotno smeri urnega kazalca (pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urnega kazalca (Negativna)</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPAInit.js" line="+2"/>
        <source>&amp;Ellipse Arc</source>
        <translation>&amp;Lok elipse</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw ellipse arc from center, major point, ratio and angles</source>
        <translation>Nariši lok elipse s pomočjo središča, glavne točke, razmera in kotov</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseArcCPPA/ts/EllipseArcCPPA_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>EllipseArcCPPA</name>
    <message>
        <location filename="../EllipseArcCPPA.js" line="+74"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Major point of ellipse or major radius</source>
        <translation>Glavna točka elipse ali velik polmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Major point of ellipse</source>
        <translation>Glavna točka elipse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Minor point of ellipse or minor radius</source>
        <translation>Druga točka elipse ali mali polmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Minor point of ellipse</source>
        <translation>Druga točka elipse</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Rotation angle</source>
        <translation>Kot rotacije</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start parameter</source>
        <translation>Začetni parameter</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End parameter</source>
        <translation>Končni parameter</translation>
    </message>
    <message>
        <location line="+267"/>
        <source>Invalid major radius.</source>
        <translation>Neveljaven velik polmer.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Major radius:</source>
        <translation>Velik polmer:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Minor radius:</source>
        <translation>Majhen polmer:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Start angle:</source>
        <translation>Začetni kot:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>End angle:</source>
        <translation>Končni kot:</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Nasprotno smeri urnega kazalca (pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urnega kazalca (Negativna)</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPAInit.js" line="+2"/>
        <source>&amp;Ellipse Arc</source>
        <translation>&amp;Lok elipse</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw ellipse arc from center, major point, ratio and angles</source>
        <translation>Nariši lok elipse s pomočjo središča, glavne točke, razmera in kotov</translation>
    </message>
</context>
</TS>
